searchData={"items":[{"type":"module","title":"Knock","doc":"Official SDK for interacting with Knock.","ref":"Knock.html"},{"type":"module","title":"Example usage - Knock","doc":"","ref":"Knock.html#module-example-usage"},{"type":"module","title":"As a module - Knock","doc":"The recommended way to configure Knock is as a module in your application. Doing so will\nallow you to customize the options via configuration in your app.\n\n```elixir\n# lib/my_app/knock.ex\n\ndefmodule MyApp.Knock do\n  use Knock, otp_app: :my_app\nend\n\n# config/runtime.exs\n\nconfig :my_app, MyApp.KnockClient,\n  api_key: System.get_env(\"KNOCK_API_KEY\")\n```\n\nIn your application you can now execute commands on your configured Knock instance.\n\n```elixir\nclient = MyApp.Knock.client()\n{:ok, user} = Knock.Users.get_user(client, \"user_1\")\n```","ref":"Knock.html#module-as-a-module"},{"type":"module","title":"Invoking directly - Knock","doc":"Optionally you can forgo implementing your own Knock module and create client instances\nmanually:\n\n```elixir\nclient = Knock.Client.new(api_key: \"sk_test_12345\")\n```","ref":"Knock.html#module-invoking-directly"},{"type":"module","title":"Customizing options - Knock","doc":"Out of the box the client will specify Tesla and Jason as the HTTP adapter and JSON client,\nrespectively. However, you can customize this at will:\n\n```elixir\nconfig :my_app, Knock,\n  adapter: Tesla.Adapter.Finch,\n  json_client: JSX\n```\n\nYou can read more about the availble adapters in the [Tesla documentation](https://hexdocs.pm/tesla/readme.html#adapters)","ref":"Knock.html#module-customizing-options"},{"type":"function","title":"Knock.notify/4","doc":"Issues a notify call, triggering a workflow with the given key.","ref":"Knock.html#notify/4"},{"type":"module","title":"Knock.Api","doc":"Api client for interacting with Knock","ref":"Knock.Api.html"},{"type":"function","title":"Knock.Api.delete/3","doc":"Executes a delete request against the Knock api.","ref":"Knock.Api.html#delete/3"},{"type":"function","title":"Knock.Api.get/3","doc":"Executes a get request against the Knock api.","ref":"Knock.Api.html#get/3"},{"type":"function","title":"Knock.Api.library_version/0","doc":"Returns the current version for the library","ref":"Knock.Api.html#library_version/0"},{"type":"type","title":"Knock.Api.options/0","doc":"Defines available options to pass to an API function","ref":"Knock.Api.html#t:options/0"},{"type":"function","title":"Knock.Api.post/4","doc":"Executes a post request against the Knock api.","ref":"Knock.Api.html#post/4"},{"type":"function","title":"Knock.Api.put/4","doc":"Executes a put request against the Knock api","ref":"Knock.Api.html#put/4"},{"type":"type","title":"Knock.Api.response/0","doc":"Describes a response from calling an API function","ref":"Knock.Api.html#t:response/0"},{"type":"module","title":"Knock.BulkOperations","doc":"Knock resources for accessing Bulk Operations","ref":"Knock.BulkOperations.html"},{"type":"function","title":"Knock.BulkOperations.get/2","doc":"Retrieves the current status of the bulk operation","ref":"Knock.BulkOperations.html#get/2"},{"type":"module","title":"Knock.Channels","doc":"Knock resources for accessing channels","ref":"Knock.Channels.html"},{"type":"function","title":"Knock.Channels.bulk_set_messages_status/4","doc":"Bulk updates channel's messages with provided action.\nSupports filtering messages to be updated with the following options:\n\n- tenants: Scope messages to the list of tenant ids\n- has_tenant: Scope to where either do or do not have a tenant present\n- recipient_ids: Scope messages to the list of recipient ids\n- engagement_status: Scope messages by engagements status: read, unread, seen,\n  unseen, archived, unarchived, interacted, link_clicked\n- archived: scopes to a particular type of archival status, one of\n  exclude, include, only\n- delivery_status: scope to only messages by delivery status, these can be the following:\n  queued, sent, undelivered, delivery_attempted, delivered\n- older_than: scope to only messages that were created before provided date\n- newer_than: scope to only messages that were created after provided date","ref":"Knock.Channels.html#bulk_set_messages_status/4"},{"type":"module","title":"Knock.Client","doc":"Sets up a configurable client that can interface with the Knock API. Expects at least\nan API key to be provided.","ref":"Knock.Client.html"},{"type":"module","title":"Example usage - Knock.Client","doc":"```elixir\n# Setup a client instance directly\nclient = Knock.Client.new(api_key: \"sk_test_12345\")\n```","ref":"Knock.Client.html#module-example-usage"},{"type":"function","title":"Knock.Client.new/1","doc":"Creates a new client struct with the provided options. The options provided must at least\ncontain an API secret key, which can be obtained in the Knock dashboard.","ref":"Knock.Client.html#new/1"},{"type":"type","title":"Knock.Client.t/0","doc":"Describes a Knock client","ref":"Knock.Client.html#t:t/0"},{"type":"module","title":"Knock.Messages","doc":"Knock resources for accessing messages","ref":"Knock.Messages.html"},{"type":"function","title":"Knock.Messages.batch_get_content/2","doc":"Returns information about the message content in batches.","ref":"Knock.Messages.html#batch_get_content/2"},{"type":"function","title":"Knock.Messages.batch_set_status/3","doc":"Batch update messages statuses: seen, read, interacted, archived, unseen, unread,\nunarchived","ref":"Knock.Messages.html#batch_set_status/3"},{"type":"function","title":"Knock.Messages.get/2","doc":"Returns information about the message.","ref":"Knock.Messages.html#get/2"},{"type":"function","title":"Knock.Messages.get_activities/3","doc":"Returns a paginated response with message's activities.\n\n# Available optional parameters:\n#\n# - page_size: specify size of the page to be returned by the api. (max limit: 50)\n# - after:  after cursor for pagination\n# - before: before cursor for pagination\n# - trigger_data: filter activities by trigger payload data","ref":"Knock.Messages.html#get_activities/3"},{"type":"function","title":"Knock.Messages.get_content/2","doc":"Returns information about the message content.","ref":"Knock.Messages.html#get_content/2"},{"type":"function","title":"Knock.Messages.get_events/3","doc":"Returns a paginated response with message's events.\n\n# Available optional parameters:\n#\n# - page_size: specify size of the page to be returned by the api. (max limit: 50)\n# - after:  after cursor for pagination\n# - before: before cursor for pagination","ref":"Knock.Messages.html#get_events/3"},{"type":"function","title":"Knock.Messages.list/2","doc":"Returns paginated messages for the provided environment\n\n# Available optional parameters:\n#\n# - page_size: specify size of the page to be returned by the api. (max limit: 50)\n# - after:  after cursor for pagination\n# - before: before cursor for pagination\n# - status: list of statuses to filter messages with\n# - tenant: tenant_id to filter messages with\n# - channel_id: channel_id to filter messages with\n# - source: workflow key to filter messages with\n# - trigger_data: trigger payload to filter messages with","ref":"Knock.Messages.html#list/2"},{"type":"function","title":"Knock.Messages.set_status/3","doc":"Sets status of message: seen, read, archived","ref":"Knock.Messages.html#set_status/3"},{"type":"function","title":"Knock.Messages.unset_status/3","doc":"Unsets status of message: unseen, unread, unarchived","ref":"Knock.Messages.html#unset_status/3"},{"type":"module","title":"Knock.Objects","doc":"Knock resources for accessing Objects","ref":"Knock.Objects.html"},{"type":"function","title":"Knock.Objects.add_subscriptions/4","doc":"Adds subscriptions for all recipients passed as arguments\n\nExpected properties:\n- recipients: list of recipients to create subscriptions for\n- properties: data to be stored at the subscription level for each recipient","ref":"Knock.Objects.html#add_subscriptions/4"},{"type":"function","title":"Knock.Objects.build_ref/2","doc":"Builds an object reference, which can be used in workflow trigger calls.","ref":"Knock.Objects.html#build_ref/2"},{"type":"function","title":"Knock.Objects.bulk_add_subscriptions/3","doc":"Creates a bulk operation to create subscriptions for a set of recipients to a\nset of objects within the given collection.\n\nEach entry in the provided subscriptions list should have the properties:\n\n- id: the id of an object for subscribing\n- recipients: a list of recipients to subscribe to the object\n- properties (optional): a map of properties to apply to each recipient subscription","ref":"Knock.Objects.html#bulk_add_subscriptions/3"},{"type":"function","title":"Knock.Objects.bulk_delete/3","doc":"Bulk deletes one or more objects in a collection.","ref":"Knock.Objects.html#bulk_delete/3"},{"type":"function","title":"Knock.Objects.bulk_set/3","doc":"Bulk upserts one or more objects in a collection.","ref":"Knock.Objects.html#bulk_set/3"},{"type":"function","title":"Knock.Objects.delete/3","doc":"Deletes the given object.","ref":"Knock.Objects.html#delete/3"},{"type":"function","title":"Knock.Objects.delete_subscriptions/4","doc":"Delete subscriptions for recipients passed as arguments\n\nExpected properties:\n- recipients: list of recipients to create subscriptions for","ref":"Knock.Objects.html#delete_subscriptions/4"},{"type":"function","title":"Knock.Objects.get/3","doc":"Gets the given object.","ref":"Knock.Objects.html#get/3"},{"type":"function","title":"Knock.Objects.get_all_preferences/3","doc":"Returns all of the users preference sets","ref":"Knock.Objects.html#get_all_preferences/3"},{"type":"function","title":"Knock.Objects.get_channel_data/4","doc":"Returns channel data for the given channel id.","ref":"Knock.Objects.html#get_channel_data/4"},{"type":"function","title":"Knock.Objects.get_messages/4","doc":"Returns paginated messages for the given object\n\n# Available optional parameters:\n#\n# - page_size: specify size of the page to be returned by the api.  (max limit: 50)\n# - after:  after cursor for pagination\n# - before: before cursor for pagination\n# - status: list of statuses to filter messages with\n# - tenant: tenant_id to filter messages with\n# - channel_id: channel_id to filter messages with\n# - source: workflow key to filter messages with\n# - trigger_data: trigger payload to filter messages with","ref":"Knock.Objects.html#get_messages/4"},{"type":"function","title":"Knock.Objects.get_preferences/4","doc":"Returns the preference set for the user.","ref":"Knock.Objects.html#get_preferences/4"},{"type":"function","title":"Knock.Objects.get_schedules/4","doc":"Returns paginated schedules for the given object\n\n# Available optional parameters:\n#\n# - page_size: specify size of the page to be returned by the api. (max limit: 50)\n# - after:  after cursor for pagination\n# - before: before cursor for pagination\n# - tenant: tenant_id to filter messages with\n# - workflow: workflow key to filter messages with","ref":"Knock.Objects.html#get_schedules/4"},{"type":"function","title":"Knock.Objects.get_subscriptions/4","doc":"Returns paginated subscriptions for the given object as recipient\n\n# Available optional parameters:\n#\n# - page_size: specify size of the page to be returned by the api. (max limit: 50)\n# - after:  after cursor for pagination\n# - before: before cursor for pagination","ref":"Knock.Objects.html#get_subscriptions/4"},{"type":"function","title":"Knock.Objects.list/3","doc":"Returns paginated list of objects for a collection\n\n# Available optional parameters:\n#\n# - page_size: specify size of the page to be returned by the api. (max limit: 50)\n# - after:  after cursor for pagination\n# - before: before cursor for pagination","ref":"Knock.Objects.html#list/3"},{"type":"function","title":"Knock.Objects.list_subscriptions/4","doc":"Returns paginated subscriptions for the given object\n\n# Available optional parameters:\n#\n# - page_size: specify size of the page to be returned by the api. (max limit: 50)\n# - after:  after cursor for pagination\n# - before: before cursor for pagination\n# - recipients: list of recipient identifiers to filter subscribers of the object","ref":"Knock.Objects.html#list_subscriptions/4"},{"type":"type","title":"Knock.Objects.ref/0","doc":"An object reference is how we refer to a particular object in a collection","ref":"Knock.Objects.html#t:ref/0"},{"type":"function","title":"Knock.Objects.set/4","doc":"Upserts the given object in the collection with the attrs provided.","ref":"Knock.Objects.html#set/4"},{"type":"function","title":"Knock.Objects.set_categories_preferences/5","doc":"Sets the category preferences for the user.","ref":"Knock.Objects.html#set_categories_preferences/5"},{"type":"function","title":"Knock.Objects.set_category_preferences/6","doc":"Sets the category preference for the user.","ref":"Knock.Objects.html#set_category_preferences/6"},{"type":"function","title":"Knock.Objects.set_channel_data/5","doc":"Upserts channel data for the given channel id.","ref":"Knock.Objects.html#set_channel_data/5"},{"type":"function","title":"Knock.Objects.set_channel_type_preferences/6","doc":"Sets the channel type preference for the user.","ref":"Knock.Objects.html#set_channel_type_preferences/6"},{"type":"function","title":"Knock.Objects.set_channel_types_preferences/5","doc":"Sets the channel type preferences for the user.","ref":"Knock.Objects.html#set_channel_types_preferences/5"},{"type":"function","title":"Knock.Objects.set_preferences/5","doc":"Sets an entire preference set for the user. Will overwrite any existing data.","ref":"Knock.Objects.html#set_preferences/5"},{"type":"function","title":"Knock.Objects.set_workflow_preferences/6","doc":"Sets the workflow preference for the user.","ref":"Knock.Objects.html#set_workflow_preferences/6"},{"type":"function","title":"Knock.Objects.set_workflows_preferences/5","doc":"Sets the workflow preferences for the user.","ref":"Knock.Objects.html#set_workflows_preferences/5"},{"type":"function","title":"Knock.Objects.unset_channel_data/4","doc":"Unsets the channel data for the given channel id.","ref":"Knock.Objects.html#unset_channel_data/4"},{"type":"module","title":"Knock.Preferences","doc":"Knock resources for accessing preferences. Note: this module and all of the functions here are\ndeprecated and will be removed in the next version.","ref":"Knock.Preferences.html"},{"type":"function","title":"Knock.Preferences.get/3","doc":"Returns the preference set for the user","ref":"Knock.Preferences.html#get/3"},{"type":"function","title":"Knock.Preferences.get_all/2","doc":"Returns all of the users preference sets","ref":"Knock.Preferences.html#get_all/2"},{"type":"function","title":"Knock.Preferences.set/4","doc":"Sets the entire preference set for the user","ref":"Knock.Preferences.html#set/4"},{"type":"function","title":"Knock.Preferences.set_categories/4","doc":"Sets the workflow preferences for the user","ref":"Knock.Preferences.html#set_categories/4"},{"type":"function","title":"Knock.Preferences.set_category/5","doc":"Sets the workflow preference for the user","ref":"Knock.Preferences.html#set_category/5"},{"type":"function","title":"Knock.Preferences.set_channel_type/5","doc":"Sets the channel type preferences for the user","ref":"Knock.Preferences.html#set_channel_type/5"},{"type":"function","title":"Knock.Preferences.set_channel_types/4","doc":"Sets the channel type preferences for the user","ref":"Knock.Preferences.html#set_channel_types/4"},{"type":"function","title":"Knock.Preferences.set_workflow/5","doc":"Sets the workflow preference for the user","ref":"Knock.Preferences.html#set_workflow/5"},{"type":"function","title":"Knock.Preferences.set_workflows/4","doc":"Sets the workflow preferences for the user","ref":"Knock.Preferences.html#set_workflows/4"},{"type":"module","title":"Knock.ResourceHelpers","doc":"","ref":"Knock.ResourceHelpers.html"},{"type":"function","title":"Knock.ResourceHelpers.maybe_json_encode_param/2","doc":"Helpers for building resources API requests","ref":"Knock.ResourceHelpers.html#maybe_json_encode_param/2"},{"type":"module","title":"Knock.Response","doc":"Represents a response back from Knock","ref":"Knock.Response.html"},{"type":"type","title":"Knock.Response.t/0","doc":"","ref":"Knock.Response.html#t:t/0"},{"type":"module","title":"Knock.Tenants","doc":"Knock resources for accessing Tenants","ref":"Knock.Tenants.html"},{"type":"function","title":"Knock.Tenants.delete/2","doc":"Deletes the given tenant.","ref":"Knock.Tenants.html#delete/2"},{"type":"function","title":"Knock.Tenants.get/2","doc":"Gets the given tenant.","ref":"Knock.Tenants.html#get/2"},{"type":"function","title":"Knock.Tenants.list/2","doc":"Returns paginated tenants for environment\n\n# Available optional parameters:\n#\n# - page_size: specify size of the page to be returned by the api. (max limit: 50)\n# - after:  after cursor for pagination\n# - before: before cursor for pagination\n# - tenant_id: id of the tenant to filter for\n# - name: name of the tenant to filter for","ref":"Knock.Tenants.html#list/2"},{"type":"function","title":"Knock.Tenants.set/3","doc":"Upserts the given tenant with the tenant data provided.","ref":"Knock.Tenants.html#set/3"},{"type":"module","title":"Knock.Users","doc":"Knock resources for accessing users","ref":"Knock.Users.html"},{"type":"function","title":"Knock.Users.bulk_delete/2","doc":"Bulk deletes the list of users given. Can accept a maximum of 100 users at a time.","ref":"Knock.Users.html#bulk_delete/2"},{"type":"function","title":"Knock.Users.bulk_identify/2","doc":"Bulk identifies the list of users given. Can accept a maximum of 100 users at a time.","ref":"Knock.Users.html#bulk_identify/2"},{"type":"function","title":"Knock.Users.bulk_set_preferences/4","doc":"Bulk sets the preferences given for the list of user ids. Will overwrite the any existing\npreferences for these users.","ref":"Knock.Users.html#bulk_set_preferences/4"},{"type":"function","title":"Knock.Users.delete/2","doc":"Issues a delete request against the user specified","ref":"Knock.Users.html#delete/2"},{"type":"function","title":"Knock.Users.get/2","doc":"Returns information about the user.","ref":"Knock.Users.html#get/2"},{"type":"function","title":"Knock.Users.get_all_preferences/2","doc":"Returns all of the users preference sets","ref":"Knock.Users.html#get_all_preferences/2"},{"type":"function","title":"Knock.Users.get_channel_data/3","doc":"Returns user's channel data for the given channel id.","ref":"Knock.Users.html#get_channel_data/3"},{"type":"function","title":"Knock.Users.get_feed/4","doc":"Returns a feed for the user with the given channel_id. Optionally supports all of the options\nfor fetching the feed.\n\n# Available optional parameters:\n#\n# - page_size: specify size of the page to be returned by the api. (max limit: 50)\n# - after:  after cursor for pagination\n# - before: before cursor for pagination\n# - status: list of statuses to filter feed items with\n# - tenant: tenant_id to filter messages with\n# - has_tenant: optionally scope items by a tenant id or no tenant\n# - archived: scope items by a given archived status (defaults to \"exclude\")\n# - trigger_data: trigger payload to filter feed items with","ref":"Knock.Users.html#get_feed/4"},{"type":"function","title":"Knock.Users.get_messages/3","doc":"Returns paginated messages for the given user\n\n# Available optional parameters:\n#\n# - page_size: specify size of the page to be returned by the api. (max limit: 50)\n# - after:  after cursor for pagination\n# - before: before cursor for pagination\n# - status: list of statuses to filter messages with\n# - tenant: tenant_id to filter messages with\n# - channel_id: channel_id to filter messages with\n# - source: workflow key to filter messages with\n# - trigger_data: trigger payload to filter messages with","ref":"Knock.Users.html#get_messages/3"},{"type":"function","title":"Knock.Users.get_preferences/3","doc":"Returns the preference set for the user.","ref":"Knock.Users.html#get_preferences/3"},{"type":"function","title":"Knock.Users.get_schedules/3","doc":"Returns paginated schedules for the given user\n\n# Available optional parameters:\n#\n# - page_size: specify size of the page to be returned by the api. (max limit: 50)\n# - after:  after cursor for pagination\n# - before: before cursor for pagination\n# - tenant: tenant_id to filter messages with\n# - workflow: workflow key to filter messages with","ref":"Knock.Users.html#get_schedules/3"},{"type":"function","title":"Knock.Users.get_subscriptions/3","doc":"Returns paginated subscriptions for the given user\n\n# Available optional parameters:\n#\n# - page_size: specify size of the page to be returned by the api. (max limit: 50)\n# - after:  after cursor for pagination\n# - before: before cursor for pagination","ref":"Knock.Users.html#get_subscriptions/3"},{"type":"function","title":"Knock.Users.get_user/2","doc":"Returns information about the user from the `user_id` given.","ref":"Knock.Users.html#get_user/2"},{"type":"function","title":"Knock.Users.identify/3","doc":"Upserts the user specified via the `user_id` with the given properties.","ref":"Knock.Users.html#identify/3"},{"type":"function","title":"Knock.Users.list/2","doc":"Returns paginated list of users\n\n# Available optional parameters:\n#\n# - page_size: specify size of the page to be returned by the api. (max limit: 50)\n# - after:  after cursor for pagination\n# - before: before cursor for pagination","ref":"Knock.Users.html#list/2"},{"type":"function","title":"Knock.Users.merge/3","doc":"Merges the user specified with `from_user_id` into the user specified with `user_id`.","ref":"Knock.Users.html#merge/3"},{"type":"function","title":"Knock.Users.set_categories_preferences/4","doc":"Sets the category preferences for the user.","ref":"Knock.Users.html#set_categories_preferences/4"},{"type":"function","title":"Knock.Users.set_category_preferences/5","doc":"Sets the category preference for the user.","ref":"Knock.Users.html#set_category_preferences/5"},{"type":"function","title":"Knock.Users.set_channel_data/4","doc":"Upserts user's channel data for the given channel id.","ref":"Knock.Users.html#set_channel_data/4"},{"type":"function","title":"Knock.Users.set_channel_type_preferences/5","doc":"Sets the channel type preference for the user.","ref":"Knock.Users.html#set_channel_type_preferences/5"},{"type":"function","title":"Knock.Users.set_channel_types_preferences/4","doc":"Sets the channel type preferences for the user.","ref":"Knock.Users.html#set_channel_types_preferences/4"},{"type":"function","title":"Knock.Users.set_preferences/4","doc":"Sets an entire preference set for the user. Will overwrite any existing data.","ref":"Knock.Users.html#set_preferences/4"},{"type":"function","title":"Knock.Users.set_workflow_preferences/5","doc":"Sets the workflow preference for the user.","ref":"Knock.Users.html#set_workflow_preferences/5"},{"type":"function","title":"Knock.Users.set_workflows_preferences/4","doc":"Sets the workflow preferences for the user.","ref":"Knock.Users.html#set_workflows_preferences/4"},{"type":"function","title":"Knock.Users.unset_channel_data/3","doc":"Unsets the user's channel data for the given channel id.","ref":"Knock.Users.html#unset_channel_data/3"},{"type":"module","title":"Knock.Workflows","doc":"Functions for interacting with Knock notify resources.","ref":"Knock.Workflows.html"},{"type":"function","title":"Knock.Workflows.bulk_create_schedules/2","doc":"Creates schedule instances in bulk.\n\nAccepts a list of schedules and creates them asynchronously.\nThe endpoint returns a BulkOperation.\n\nEach schedule in the list should contain:\n- recipient: recipient for the schedule to be created for\n- actor: actor to be used when trigger the target workflow\n- repeats: repeat rules to specify when the workflow must be triggered\n- data: data to be used as variables when the workflow runs\n- tenant: tenant to be used for when the workflow runs\n- scheduled_at: ISO-8601 formatted date time for when the schedule should start\n- ending_at: ISO-8601 formatted date time for when the schedule should end","ref":"Knock.Workflows.html#bulk_create_schedules/2"},{"type":"function","title":"Knock.Workflows.cancel/4","doc":"Cancels the workflow with the given cancellation key.\n\nCan optionally be provided with:\n\n- `recipients`: A list of recipients to cancel the notify for","ref":"Knock.Workflows.html#cancel/4"},{"type":"function","title":"Knock.Workflows.create_schedules/3","doc":"Creates schedule instances for the specified recipients on the properties map.\n\nExpected properties:\n- recipients: list of recipients for schedules to be created for\n- actor: actor to be used when trigger the target workflow\n- repeats: repeat rules to specify when the workflow must be triggered\n- data: data to be used as variables when the workflow runs\n- tenant: tenant to be used for when the workflow runs","ref":"Knock.Workflows.html#create_schedules/3"},{"type":"function","title":"Knock.Workflows.delete_schedules/2","doc":"Delete schedule instances.","ref":"Knock.Workflows.html#delete_schedules/2"},{"type":"function","title":"Knock.Workflows.list_schedules/3","doc":"Returns paginated schedules for the provided environment\n\n# Available optional parameters:\n#\n# - page_size: specify size of the page to be returned by the api. (max limit: 50)\n# - after:  after cursor for pagination\n# - before: before cursor for pagination\n# - tenant: tenant_id to filter schedues with\n# - recipients: list of recipients to filter schedules with","ref":"Knock.Workflows.html#list_schedules/3"},{"type":"function","title":"Knock.Workflows.trigger/4","doc":"Executes a notify call for the workflow with the given key.\n\nNote: properties must contain at least `recipents` for the call to be valid.\n\nOptions can include:\n* `idempotency_key`: A unique key to prevent duplicate requests","ref":"Knock.Workflows.html#trigger/4"},{"type":"function","title":"Knock.Workflows.update_schedules/3","doc":"Updates schedule instances with argument properties.\n\nExpected properties:\n- actor: actor to be used when trigger the target workflow\n- repeats: repeat rules to specify when the workflow must be triggered\n- data: data to be used as variables when the workflow runs\n- tenant: tenant to be used for when the workflow runs","ref":"Knock.Workflows.html#update_schedules/3"},{"type":"exception","title":"Knock.ApiKeyMissingError","doc":"Exception for when a request is made without an API key.","ref":"Knock.ApiKeyMissingError.html"},{"type":"extras","title":"Knock","doc":"# Knock\n\nKnock API access for applications written in Elixir.","ref":"readme.html"},{"type":"extras","title":"Documentation - Knock","doc":"See the [package documentation](https://hexdocs.pm/knock) as well as [API documentation](https://docs.knock.app) for usage examples.","ref":"readme.html#documentation"},{"type":"extras","title":"Installation - Knock","doc":"Add the package to your `mix.exs` file as follows:\n\n```elixir\ndef deps do\n  [\n    {:knock, \"~> 0.4\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Configuration - Knock","doc":"Start by defining an Elixir module for your Knock instance:\n\n```elixir\ndefmodule MyApp.Knock do\n  use Knock, otp_app: :my_app\nend\n```\n\nTo use the library you must provide a secret API key, provided in the Knock dashboard.\n\nYou can set it as an environment variable:\n\n```bash\nKNOCK_API_KEY=\"sk_12345\"\n```\n\nOr you can specify it manually in your configuration:\n\n```elixir\nconfig :my_app, MyApp.Knock,\n  api_key: \"sk_12345\"\n```\n\nOr you can pass it through when creating a client instance:\n\n```elixir\nknock_client = MyApp.Knock.client(api_key: \"sk_12345\")\n```","ref":"readme.html#configuration"},{"type":"extras","title":"Usage - Knock","doc":"","ref":"readme.html#usage"},{"type":"extras","title":"Identifying users - Knock","doc":"```elixir\nMyApp.Knock.client()\n|> Knock.Users.identify(\"jhammond\", %{\n  \"name\" => \"John Hammond\",\n  \"email\" => \"jhammond@ingen.net\",\n})\n```","ref":"readme.html#identifying-users"},{"type":"extras","title":"Retrieving users - Knock","doc":"```elixir\nMyApp.Knock.client()\n|> Knock.Users.get_user(\"jhammond\")\n```","ref":"readme.html#retrieving-users"},{"type":"extras","title":"Sending notifies - Knock","doc":"```elixir\nMyApp.Knock.client()\n|> Knock.Workflows.trigger(\"dinosaurs-loose\", %{\n  # user id of who performed the action\n  \"actor\" => \"dnedry\",\n  # list of user ids for who should receive the notif\n  \"recipients\" => [\"jhammond\", \"agrant\", \"imalcolm\", \"esattler\"],\n  # an optional cancellation key\n  \"cancellation_key\" => alert.id,\n  # an optional tenant\n  \"tenant\" => \"jurassic-park\",\n  # data payload to send through\n  \"data\" => %{\n    \"type\" => \"trex\",\n    \"priority\" => 1,\n  },\n})\n```","ref":"readme.html#sending-notifies"},{"type":"extras","title":"User preferences - Knock","doc":"```elixir\nclient = MyApp.Knock.client()\n\n# Set preference set for user\nKnock.Users.set_preferences(client, \"jhammond\", %{channel_types: %{email: true}})\n\n# Set granular channel type preferences\nKnock.Users.set_channel_type_preferences(client, \"jhammond\", :email, true)\n\n# Set granular workflow preferences\nKnock.Users.set_workflow_preferences(client, \"jhammond\", \"dinosaurs-loose\", %{\n  channel_types: %{email: true}\n})\n\n# Retrieve preferences\nKnock.Users.get_preferences(client, \"jhammond\")\n```","ref":"readme.html#user-preferences"},{"type":"extras","title":"Getting and setting channel data - Knock","doc":"```elixir\nclient = MyApp.Knock.client()\n\n# Set channel data for an APNS\nKnock.Users.set_channel_data(client, \"jhammond\", KNOCK_APNS_CHANNEL_ID, %{\n  tokens: [apns_token],\n})\n\n# Get channel data for the APNS channel\nKnock.Users.get_channel_data(client, \"jhammond\", KNOCK_APNS_CHANNEL_ID)\n```","ref":"readme.html#getting-and-setting-channel-data"},{"type":"extras","title":"Canceling notifies - Knock","doc":"```elixir\nMyApp.Knock.client()\n|> Knock.Workflows.cancel(\"dinosaurs-loose\", alert.id, %{\n  # optional list of user ids for who should have their notify canceled\n  \"recipients\" => [\"jhammond\", \"agrant\", \"imalcolm\", \"esattler\"],\n})\n```","ref":"readme.html#canceling-notifies"},{"type":"extras","title":"Signing JWTs - Knock","doc":"You can use the excellent `joken` package to [sign JWTs easily](https://hexdocs.pm/joken/assymetric_cryptography_signers.html#using-asymmetric-algorithms).\nYou will need to generate an environment specific signing key, which you can find in the Knock dashboard.\n\nIf you're using a signing token you will need to pass this to your client to perform authentication.\nYou can read more about [clientside authentication here](https://docs.knock.app/client-integration/authenticating-users).\n\n```elixir\npriv = System.get_env(\"KNOCK_SIGNING_KEY\")\nnow = DateTime.utc_now()\n\nclaims = %{\n  # The user id to sign this key for\n  \"sub\" => user_id,\n  # When the token was issued\n  \"iat\" => DateTime.to_unix(now),\n  # When the token expires (1 hour)\n  \"exp\" => DateTime.add(now, 3600, :second) |> DateTime.to_unix()\n}\n\n\nsigner = Joken.Signer.create(\"RS256\", %{\"pem\" => priv})\n{:ok, token, _} = Joken.generate_and_sign(%{}, claims, signer)\n```","ref":"readme.html#signing-jwts"},{"type":"extras","title":"LICENSE","doc":"MIT License\n\nCopyright (c) 2021 Knock Labs, Inc.\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the \"Software\"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.","ref":"license.html"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}